REDCapSync: Encapsulated 'REDCap' Projects for Synchronized Data Pipelines
Source:R/REDCapSync-package.R
REDCapSync-package.RdWraps dozens of 'REDCap' API endpoints into a standardized R6 object. Research Electronic Data Capture ('REDCap') is a survey and database web application software maintained by Vanderbilt University. It has a robust application programming interface (API) utilized by several R packages. 'REDCapSync' uses 'redcapAPI' and 'REDCapR' behind-the-scenes to retrieve all metadata, data, and log details for a project. To minimize unnecessary server calls, the interim 'REDCap' log is analyzed and used to only update necessary records. Furthermore, the user can define custom datasets that save to a directory. Those datasets continue to refresh when projects are synced. Having a secure, standardized, API-efficient, project-agnostic R object for 'REDCap' projects, streamlines downstream use in scripts, functions, and shiny applications.
Author
Maintainer: Brandon Rose thecodingdocs@gmail.com (ORCID) [copyright holder]
Authors:
Brandon Rose thecodingdocs@gmail.com (ORCID) [copyright holder]
Other contributors:
Natalie Goulett [contributor]