Finds the location of the cache established by hoard
and deletes stored project information (not data)! If you provide
project_names, it will remove only those projects from the cache. If you
want to truly delete the project files, you must do so at the project
directory you set up.
Details
The cache only stores information like project_name, token_name, directory
location, and other details from setup_project().The default location of
the cache location is defined by using R_USER_CACHE_DIR if set. Otherwise,
it follows platform conventions via hoardr::hoardr, saving a file
"R/REDCapSync/projects.rds". No direct project data is stored in the cache.
Notably, tokens and data are not stored here. The key variables stored in
the cache are...
project_name- unique identifier for REDCapSync packageredcap_uri- server locationtoken_name- where to find token environment withSys.getenv()dir_path- where to saved project and associated files locallyproject_id- obtained from API call and "locks-in" the connectionredcap_version- obtained from API call and affects linkslast_syncandsync_frequency- informs REDCap sync of when to updateother variables from project info and some internal package mechanics
See also
vignette("Cache", package = "REDCapSync")
Other Cache Functions:
projects