Skip to contents

Finds the location of the cache established by hoard and deletes stored project information (not data)! If you provide project_names, it will remove only those projects from the cache.

Usage

cache_clear(project_names = NULL)

Arguments

project_names

character vector of project project_names previously setup. If NULL, will get all from get_projects()

Value

Message of outcome and invisible NULL.

Details

The cache only stores information like project_name, token_name, directory location, and other details from setup_project(). If you want to truly delete the project files, you must do so at the project directory you set up.

Examples

if (FALSE) { # \dontrun{
cache_clear("OLD_PROJECT")
cache_clear() # every project
} # }