Skip to contents

Everytime a project is synced, basic project information is saved to the package user cache so that load_project and sync work across R sessions.

Usage

get_projects()

Value

data.frame of projects from the cache

data.frame of cached projects

Details

No direct project data is stored in the cache. Notably, tokens and data are not stored here. The key variables stored in the cache are...

  • project_name - unique identifier for REDCapSync package

  • redcap_uri - server location

  • token_name - where to find token environment with Sys.getenv()

  • dir_path - where to saved project and associated files locally

  • project_id - obtained from API call and "locks-in" the connection

  • redcap_version - obtained from API call and affects links

  • last_sync and sync_frequency - informs REDCap sync of when to update

  • other variables from project info and some internal package mechanics