Everytime a project is synced, basic project information is saved to the package user cache so that load_project and sync work across R sessions.
Details
No direct project data is stored in the cache. Notably, tokens and data are not stored here. The key variables stored in the cache are...
project_name- unique identifier for REDCapSync packageredcap_uri- server locationtoken_name- where to find token environment withSys.getenv()dir_path- where to saved project and associated files locallyproject_id- obtained from API call and "locks-in" the connectionredcap_version- obtained from API call and affects linkslast_syncandsync_frequency- informs REDCap sync of when to updateother variables from project info and some internal package mechanics
See also
vignette("Cache", package = "REDCapSync")
Other Cache Functions:
cache_clear()